@@ -13,11 +13,11 @@ class TestEval(unittest.TestCase):
         parser, _ = tfkit.eval.parse_eval_args(
             ['--model', 'onebyone', '--metric', 'emf1', '--valid', 'test.csv', '--print'])
         print(parser)
-        self.assertTrue(parser.get('model') == 'onebyone')
+        self.assertTrue(parser.get('model') == ['onebyone'])
 
         eval_parser, model_parser = tfkit.eval.parse_eval_args(
             ['--model', 'onebyone', '--metric', 'emf1', '--valid', 'test.csv', '--print', '--decodenum', '2'])
-        self.assertTrue(eval_parser.get('model') == 'onebyone')
+        self.assertTrue(eval_parser.get('model') == ['onebyone'])
         self.assertTrue(model_parser.get('decodenum') == '2')
 
     def testEvalGen(self):
@@ -96,8 +96,14 @@ class TestEval(unittest.TestCase):
 
     def testEvalAddedTokenModel(self):
         result = os.system(
-            'tfkit-eval --model ' + ADDTOK_MODEL_PATH + ' --config ' + ADDTOK_TOK_PATH + ' --valid ' + ADDTOK_DATASET + ' --metric emf1 --print')
+            'tfkit-eval --model ' + ADDTOKFILE_MODEL_PATH + ' --valid ' + ADDTOK_DATASET + ' --metric emf1 --print')
         self.assertTrue(result == 0)
         result = os.system(
-            'tfkit-eval --model ' + ADDTOK_MODEL_PATH + ' --config ' + ADDTOK_TOK_PATH + ' --valid ' + ADDTOK_DATASET + ' --metric emf1 --print')
+            'tfkit-eval --model ' + ADDTOKFILE_MODEL_PATH + ' --valid ' + ADDTOK_DATASET + ' --metric emf1 --print')
+        self.assertTrue(result == 0)
+        result = os.system(
+            'tfkit-eval --model ' + ADDTOKFREQ_MODEL_PATH + ' --valid ' + ADDTOK_DATASET + ' --metric emf1 --print')
+        self.assertTrue(result == 0)
+        result = os.system(
+            'tfkit-eval --model ' + ADDTOKFREQ_MODEL_PATH + ' --valid ' + ADDTOK_DATASET + ' --metric emf1 --print')
         self.assertTrue(result == 0)
