@@ -22,19 +22,28 @@ def check_type_for_dataloader(data_item):
         return False
 
 
-def dataloader_collate(batch):
-    batch = copy.deepcopy(batch)
-    has_pad = all([dat['input'][-1] == batch[0]['input'][-1] for dat in batch])
+def batch_reduce_pad(batch):
+    has_pad = all([dat['input'][-1] == batch[0]['input'][-1] for dat in batch]) and \
+              batch[0]['input'][-1] == batch[0]['input'][-2]
     if has_pad:
-        pad_token = batch[0]['input'][-1]
-        pad_start = max([list(dat['input']).index(pad_token) for dat in batch])
+        pad_token_input = batch[0]['input'][-1]
+        pad_start = max([list(dat['input']).index(pad_token_input) for dat in batch])
+        pad_token_target = batch[0]['target'][-1] if 'target' in batch[0] else None
+        if isinstance(pad_token_target, int):
+            pad_start = max(pad_start, max([list(dat['target']).index(pad_token_target) for dat in batch]))
         for ind, dat in enumerate(batch):
             for k, v in dat.items():
-                if isinstance(v, numpy.ndarray) and v.size > 1:
+                if (isinstance(v, numpy.ndarray) and v.size > 1) or (isinstance(v, list) and len(v) > 1) and \
+                        'prev' != k and 'decoder_mask' != k:
                     batch[ind][k] = v[:pad_start]
                 if k == 'input_length':
                     batch[ind][k] = pad_start - 1
-    return torch.utils.data._utils.collate.default_collate(batch)
+    return batch
+
+
+def dataloader_collate(batch):
+    batch = copy.deepcopy(batch)
+    return torch.utils.data._utils.collate.default_collate(batch_reduce_pad(batch))
 
 
 def get_dataset(file_path, model_class, tokenizer, parameter):
@@ -56,8 +65,6 @@ def get_dataset(file_path, model_class, tokenizer, parameter):
 
 class LoadDataset(data.Dataset):
     def preprocess(self, i):
-        tasks, task, input_text, target, *other = i
-        self.task_dict.update(tasks)
         sample = []
         for get_feature_from_data, feature_param in self.preprocessing_data(i, self.tokenizer, **self.input_arg):
             for feature in get_feature_from_data(**feature_param):
@@ -80,8 +87,10 @@ class LoadDataset(data.Dataset):
                 self.task_dict = outdata['task']
         else:
             sample = []
-            [sample.extend(i) for i in process_map(self.preprocess, list(get_data_from_file(fpath)),
-                                                   max_workers=input_arg['worker'],
+            all_data = list(get_data_from_file(fpath))
+            [self.task_dict.update(i[0]) for i in all_data]
+            [sample.extend(i) for i in process_map(self.preprocess, all_data,
+                                                   max_workers=input_arg.get('worker', 4),
                                                    chunksize=1000)]
             print(f"There are {len(sample)} datas after preprocessing.")
             if cache:
